;**************************************************************
; DALLAS casovani jednovodicove sbernice
;**************************************************************
; fosc = 4 MHz
; rychlost prenosu dat priblizne 16 kB/sec
;..............................................................
; DS I/O vyvod je RB0
; nakonfigurovanim I/O vyvodu jako vystupu je tento
; vyvod nastaven do nuly
; je-li vyvod ve funkci vstupu, jednicka na nem je nastavena
; pomoci PULL-UP rezistoru 
; !!proto musi byt pred pouzitim tohoto podprogramu prislusne
; bity datoveho registru nastaveny do nuly!!
;..............................................................
; pri operacich s DSxxxx je po dobu RESET sekvence, vyslani bytu
; a precteni bytu zakazano preruseni
;***************************************************************
; Definice symbolu
;**************************************************************
TMP1	equ	10h
PSW	equ	11h
T_RDS	equ	12h
BITSDS	equ	13h
f	equ	1
SWR	equ	03h
PortB	equ	06h
#define	RP0	SWR,5
#define	C	SWR,0
#define	DS	PortB,0
#define	PRESEN	PSW,0
;**************************************************************
; Cekaci smycky pro casovani DALLAS sbernice
;**************************************************************
; cekej min. 480 mikrosekund  
; konstanta 9eh pro fosc = 4 MHz RESET pulz (482 mikrosekund)
;**************************************************************
cek480	movlw	9eh	
	goto	cek
;**************************************************************
; cekej 405 mikrosekund - po teto dobe mohou byt po PRESENC 
; vysilana data 
; konstanta 83h pro fosc = 4 MHz (406 mikrosekund)
;**************************************************************
cek405	movlw	83h	
	goto	cek
;**************************************************************
; cekej 60 mikrosekund - cekani na PRESENC pulz
; Presenc pulz testuj v dobe 15 mikrosekund po tomto cekani
; konstanta 11h pro fosc = 4 MHz (cteni za 61 mikrosekund)
;**************************************************************
cek60	movlw	11h
	goto	cek
;**************************************************************
; cekej 46 mikrosekund - cekani na dalsi cteni dat
; konstanta 0eh pro fosc = 4 MHz (46 mikrosekund)
;**************************************************************
cek46	movlw	0eh
;..............................................................
cek	movwf	TMP1
cek1	decfsz	TMP1,f
	goto	cek1
	return

;**************************************************************
; Vyslani RESET a cteni PRESENCE pulzu po jednovodicove DALLAS
; sbernici
; Pokud PRESENCE pulz prisel, nastavi se ve stavovem slovu programu PSW
; bit PRESEN
;.......................................
; vysle reset, ktery tva 487 mikrosekund
; ceka 65 mikrosekund a po te precte datovou linku 
; (PRESENC pulz = 0) 
;**************************************************************
resds	bsf	RP0		;prace s TRIS registry
	bcf	DS		;vysli reset pulz
	call	cek480
	bsf	DS		;ukonci reset pulz
	bcf	RP0		;prace s datovymi registry
	call	cek60		;cekej 60 mikrosekund
	bsf	PRESEN		;precti presence pulz
	btfsc	DS
	bcf	PRESEN
;................................
	call	cek405		;pockej 405 mikrosekund
;................................
	return
;**************************************************************
; Precti byte z DSxxxx do T_RDS registru
; po jednovodicove DALLAS sbernici
;.................................
; odstartuje se cteni pulzem dlouhym 5 mikrosekund
; pote se uvolni sbernice a po deseti mikrosekundach se precte
; datova sbernice (bit dat)
; data se ctou po bytech vzdy od LSB
;**************************************************************
rdds	movlw	08h		;nastav pocet ctenych bitu
	movwf	BITSDS
;...............................	
rdb1	bsf	RP0
	bcf	DS		;nastav vystup do nuly
;...............................
	goto	rdb2		;cekej 5 mikrosekund
rdb2	goto	rdb20		;!!!pro fosc = 4 MHz!!!
rdb20	nop
	bsf	DS		;uvolni datovou linku
	bcf	RP0
;...............................
	goto	rdb3		;cekej 10 mikrosekund
rdb3	goto	rdb4
rdb4	goto	rdb40		;!!!pro fosc = 4 MHz!!!
rdb40	bcf	C
;...............................
	btfsc	DS		;datovy bit do C bitu
	bsf	C
;................................
	rrf	T_RDS,f		;presun datovy bit do T_RDS
	call	cek46		;cekej, az bude mozne cist dalsi bit
	decfsz	BITSDS,f	
	goto	rdb1
;...............................
	movfw	T_RDS
	return
;***************************************************************
; Vysli byte dat ulozeny v T_RDS registru
; po jednovodicove DALLAS sbernici
;...................................
; zapis jednicky - pulz dlouhy 5 mikrosekund
; zapis nuly - pulz dlouhy 60 mikrosekund
; data jsou zapisovana po bytech vzdy od LSB
;**************************************************************
wrds	movwf	T_RDS
;................................
	movlw	08		;nastav pocet vysilanych bitu
	movwf	BITSDS	
	bsf	RP0		;vyber TRIS registry
wrb1	rrf	T_RDS,f		;jako prvni je vysilany LSB
	bcf	DS		;nastav vystup do nuly
	btfss	C		;vysilani jednicky
	call	cek60
	goto	wrb10		;!!!pro fosc = 4 MHz!!!
wrb10	bsf	DS		;nastav vystup do jednicky
	btfsc	C
	call	cek60
	decfsz	BITSDS,f
	goto	wrb1
	bcf	RP0		;nastav banku 0
;...............................
	return
;...............................
	end